% beispiele.m
% Kapitel 3: Eingabe und Ausgabe in MATLAB
%            Beispiele zum Skript

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
format compact     % Ermglicht kompakte Ausgabe ohne Leerzeilen

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %% 3.1 Steuerung der Bildschirmausgabe

echo mittelwerte on
[A, G] = mittelwerte (1:2:7)
echo mittelwerte off

for i=1:2:6
    disp (i)
    pause (i)
end
disp ('Ende')
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3.2 Benutzerdialoge

text = ['Das ist', ' ', 'ein Text!']
whos text

preis = input (['Wieviel kostet heuer \n', ...
                'die Wies''n-Ma ?      ']);
waehrung = input ('Whrung ?             ', 's');

disp (['Aber ', num2str(preis, '%0.2f'), ' ', waehrung, ...
       ' pro Ma wird ein teurer Rausch!'])
disp (' ')                                                   % Leerzeile
ausgabe = sprintf ('Zwei Ma kosten dann %2.2f %s.', ...
                    preis*2, waehrung);
disp (ausgabe)
mehr = sprintf ('%4d Ma kosten dann %2.2f.\n', ...
                [3:5; (3:5)*preis]);
disp (mehr)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3.3 Import und Export von Daten
%      Die folgenden Zeilen bentigen Schreibrecht im aktuellen Verzeichnis
%      andernfalls bitte auskommentieren

clear

test_vektor = [0:0.1:10]';                       % Spaltenvektor
test_matrix = [test_vektor cos(test_vektor)];    % Matrix

save test                          % Speichern in Datei test.mat
clear                              % Workspace lschen
load test                          % Laden aus Datei test.mat
who                                % Anzeige des Workspace

save test.txt -ascii test_matrix   % Speichern in Datei test.txt
clear                              % Workspace lschen
load test.txt                      % Laden aus Datei test.txt
who                                % Anzeige des Workspace

%% fprintf

preis = 7.90;
bier_id = fopen ('bier.txt', 'w');
fprintf (bier_id, '%s\r\n', 'Bierpreis-', 'Hochrechnung');   % Kopfzeilen
fprintf (bier_id, '%4d Ma kosten dann %2.2f.\r\n', ...
                    [3:5; (3:5)*preis]);
fclose (bier_id);

%% Alternativ mit Cell-Array fr Kopfzeilen

kopfzeilen = {'Bierpreis-', 'Hochrechnung'};
bier_id = fopen ('bier.txt', 'w');
fprintf (bier_id, '%s\r\n', kopfzeilen{:});  % Kopfzeilen
fprintf (bier_id, '%4d Ma kosten dann %2.2f.\r\n', ...
                    [3:5; (3:5)*preis]);
fclose (bier_id);

%% textread

zeilen = textread ('chaos.txt',  '%s', ...  % Datei und Formatstring
                   'delimiter',  '\n', ...  % Zeilenumbruch als Trennzeichen
                   'whitespace', '')        % kein Zeichen berspringen

matrix = textread ('chaos.txt',   '',   ... % Datei und (leerer) Formatstring
                   'delimiter',   ',',  ... % Komma als Trennzeichen
                   'whitespace',  '* ', ... % berspringt * und Leerzeichen
                   'headerlines', 1,    ... % berspringt die erste Zeile
                   'emptyvalues', NaN)      % ersetzt leere Felder durch NaN

%% dlmread

matrix = dlmread ('chaos.txt', ',', 'A2..C3')  % Datei, Trennzeichen, Bereich

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3.4 Betriebssystemaufruf und Dateiverwaltung

mkdir ('testverzeichnis')
verzeichnis = dir ('testverzeich*');
eval (['!rmdir ', verzeichnis.name])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3.5 Graphische Darstellung

figure
plot (diff (primes (500)))              % Abstand zwischen Primzahlen < 500
get (gcf)
get (gcf, 'Position')
set (gcf, 'Position', [10 50 400 200])

title ('berschrift', 'FontSize', 16, 'FontWeight', 'Bold')
plot (diff (primes (500)), 'r', 'LineWidth', 2.0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Zweidimensionale Graphiken

figure                                            % Erzeugt neue Figure
subplot (121)                                     % Linker Subplot
    plot (-5:0.1:5, cos ((-5:0.1:5)*pi), 'k:')    % schwarz, gepunktet
    hold on                                       % alten Plot beibehalten
    fplot ('2*sin(pi*x)/(pi*x)', [-5 5], 'k--')   % schwarz, gestrichelt
subplot (122)                                     % Rechter Subplot
    t = (0:20)*0.9*pi;
    plot (cos (t), sin (t))                       % Standard: blaue Linie

figure
subplot (121)
    ezplot ('x^2 - y^2 -2')
subplot (122)
    ezplot ('sin(3*t) * cos(t) / (t+pi)', 'sin(3*t) * sin(t) / (t+pi)', [0,4*pi])
        
%% Berechnung des Frequenzgangs eines Tiefpasses und Hochpasses mit
%  der Zeitkonstante T im Laplace-Bereich: 1/(1+sT) mit s = j*omega

T                 = 0.05;                        % Zeitkonstante [s]
omega             = logspace (0, 3, 100);        % Frequenzvektor [rad/s]
frequenzgang_TP   = (T*j*omega + 1).^(-1);       % Frequenzgang Tiefpass
frequenzgang_HP   = 1 - frequenzgang_TP;         % Frequenzgang Hochpass

figure (3)                                       % Erzeugt Figure 3
clf                                              % Lscht ggf. alte Plots

subplot (121)                                    % Linker Subplot: Amplitude
    loglog (omega, abs (frequenzgang_TP), '-')   % Amplitudengang Tiefpass
    hold on
    loglog (omega, abs (frequenzgang_HP), '--')  % Amplitudengang Hochpass
    loglog ([1 1]/T, [0.01 10], ':')             % Linie Zeitkonstante
    text (1.1/T, 0.02, 'Zeitkonstante')          % Text Zeitkonstante
    title ('bertragungsfunktionen')             % Titel linker Subplot
    xlabel ('\omega [rad s^-^1]')                % Achsenbeschriftung X
    ylabel ('Amplitude [dB]')                    % Achsenbeschriftung Y
    legend ('Tiefpass', 'Hochpass', 2)           % Legende links oben
    xlim ([1 1e3])                               % Skalierung x-Achse
    skala = -40:20:40;                           % Gewnschte Achsteilung
    set (gca, 'ytick', 10.^(skala/20))           % Setzt Achsteilung (dB)
    set (gca, 'yticklabel', skala)               % Setzt Beschriftung

subplot (122)                                    % Rechter Subplot: Phase
    semilogx (omega, angle (frequenzgang_TP) *180/pi, '-')  % Phasengang TP
    hold on
    semilogx (omega, angle (frequenzgang_HP) *180/pi, '--') % Phasengang HP
    grid on                                      % Aktiviert Gitterlinien
    xlabel ('\omega [rad s^-^1]')                % Achsenbeschriftung X
    ylabel ('Phase [Grad]')                      % Achsenbeschriftung Y
    axis ([1 1e3 -90 90])                        % Skalierung x- und y-Achse
    skala = -90:30:90;                           % Gewnschte Achsteilung
    set (gca, 'ytick', skala)                    % Setzt Achsteilung (Grad)
    set (gca, 'yticklabel', skala)               % Setzt Beschriftung

figure
tiefpass = tf ([1], [0.05 1]);
hochpass = 1 - tiefpass;
bode (tiefpass, 'b-', hochpass, 'r--')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Dreidimensionale Graphiken (3D-Graphik)

figure (5)
phi = (0:100) / 100 * 2*pi;
plot3 (-sin (2*phi), cos (3*phi), 1.5*phi, 'k.-')
grid on

%% Beispiel

x = 0:0.05:2;
y = -1:0.2:1;

[X, Y] = meshgrid (x, y);       % Erzeugt Matrizen ber Bereich von x, y
Z      = (Y+1) .* cos (2*X.^2) + (Y-1) .* sin (2*X.^2) / 5;

figure
subplot (221)
    surf (X, Y, Z)
    view (-40, 30)
    title ('surf (X, Y, Z); view (-40, 30)')
subplot (222)
    mesh (X, Y, Z)
    view (-20, 30)
    title ('mesh (X, Y, Z); view (-20, 30); grid off; box on')
    grid off
    box on
subplot (223)
    waterfall (X, Y, Z)
    view (-20, 10)
    title ('waterfall (X, Y, Z); view (-20, 10)')
subplot (224)
    contour (X, Y, Z)
    title ('contour (X, Y, Z)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Importieren, Exportieren und Drucken von Graphiken
%  Bilder Einbinden

figure
foto_variable = imread ('foto.jpg', 'jpeg');
image (foto_variable)
axis ('equal', 'tight')

%% Drucken

% print -f1;                % Drucken von Figure 1 auf Standarddrucker
% print -f1 -dmeta 'bild';  % Speichern als Windows-Metafile (bild.emf)
% print -f1 -depsc 'bild';  % Speichern als Farb-Postscript  (bild.eps)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 3.7 Tipps rund um die MATLAB-Figure

x = 0:4;
y = rand (5);      % 5 x 5 Matrix

figure
subplot (211)
    for k = 1:5
        plot (x, y(k,:), 'o--', 'LineWidth', 3, 'Color', [1 0.7 0]*k/5)
        text (x(1)+0.2, y(k,1)+0.1, num2str (y(k,1), '%3.2f')) % Beschriftung von Datenpunkten   
        hold on
        legendtext {k} = ['Datensatz ',num2str(k)];  % Legende iterativ zusammensetzen
    end
    h = legend (legendtext);                         % Legende ausgeben
    set (h, 'FontName', 'Courier')                   % Legendentext formatieren
    title ('Text', 'FontName', 'Times', ...)         % Titel formatieren
                   'FontSize', 16, ...
                   'FontWeight', 'Bold')
    ylabel({'Zeile 1';'Zeile 2'})                    % Mehrzeiliger Text
%     ylabel ('Zeile 1\newlineZeile 2')              % Mehrzeiliger Text (alternativ)
    set (gca, 'XTick', [1:3], ...                    % Setzt Achsteilung
              'XTickLabel', {'A', 'B', 'C'})         % Setzt Beschriftung

subplot (212)
    set (gca, 'Visible', 'off')                      % Erstellt unsichtbares AXES-Objekt
    text (0, 1, {'Dieser Text ist in einem unsichtbaren'; ...   % Textblock in Figure
                 'AXES-Objekt verankert.'})

    text ('Position', [0.5 0.3], ...                 % Formelausgabe mt LaTeX-Interpreter
          'Interpreter', 'latex', ...
          'FontSize', 16, ...
          'String', '$$\hat \alpha Test_{ab} \cdot \frac{a}{b}$$')

set (gcf, 'PaperUnits', 'normalized', ...            % Druckerausgabe formatieren
          'PaperPosition', [0.05 0.10 0.90 0.80])
set (gcf, 'PaperOrientation', 'landscape', ...
          'PaperType', 'A4')

% print -f1 -dps -append 'test'                      % Ausgabe auf fortlaufenden Seiten

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
format
